@@ -11,7 +11,7 @@ from typing import Dict, List, Optional, Tuple, Union
 import libcst as cst
 from libcst.codemod import CodemodContext, VisitorBasedCodemodCommand
 from libcst.codemod.visitors import AddImportsVisitor, GatherImportsVisitor, ImportItem
-from stubber.cst_transformer import StubTypingCollector, update_def_docstr, update_module_docstr, TypeInfo, MODULE_KEY
+from stubber.cst_transformer import MODULE_KEY, StubTypingCollector, TypeInfo, update_def_docstr, update_module_docstr
 
 ##########################################################################################
 log = logging.getLogger(__name__)
@@ -66,8 +66,12 @@ class MergeCommand(VisitorBasedCodemodCommand):
         self.stub_imports: Dict[str, ImportItem] = {}
         # parse the doc-stub file
         if self.stub_source:
-            # parse the doc-stub file
-            stub_tree = cst.parse_module(self.stub_source)
+            try:
+                # parse the doc-stub file
+                stub_tree = cst.parse_module(self.stub_source)
+            except cst.ParserSyntaxError as e:
+                log.error(f"Error parsing {self.stub_path}: {e}")
+                return
             # create the collectors
             typing_collector = StubTypingCollector()
             import_collector = GatherImportsVisitor(context)
@@ -151,7 +155,7 @@ class MergeCommand(VisitorBasedCodemodCommand):
         new = self.annotations[stack_id]
 
         # first update the docstring
-        updated_node = update_def_docstr(updated_node, new.docstr_node)
+        updated_node = update_def_docstr(updated_node, new.docstr_node, new.def_node)
         # Sometimes the firmware stubs and the doc stubs have different types : FunctionDef / ClassDef
         # we need to be carefull not to copy over all the annotations if the types are different
         if new.def_type == "funcdef":
